'''
hive read helper

use pyarrow+thrift to read and write hive, choose this function is because
it's speed is faster than the other pkg-tools pyhive and impyla 

author: qin hai ning
date: 2021-03-25
'''


class HiveHelper(object):
    '''
    hive control of insert delete update query
    '''
    def __init__(self):
        pass

    def connect(self):

